####################################
Time Series (:mod:`gwpy.timeseries`)
####################################

.. automodule:: gwpy.timeseries

.. seealso::

    - **User Guide**: :doc:`/timeseries/index`
    - **Examples**: :doc:`/examples/timeseries/index`

.. automodapi:: gwpy.timeseries
    :include-all-objects:
    :no-heading:
    :no-main-docstr:
